@@ -2,7 +2,9 @@
 
 #include <stdio.h>
 #include <stdlib.h>
-#include<math.h>
+#include <math.h>
+#include <R_ext/Rdynload.h>
+
 
 /* for random number generator in R */
 #include <R.h>
@@ -188,11 +190,13 @@ void adkTestStat(double *adk, int k, double *x, int *ns){
 	/* fij records the number of observations in the ith 
         sample coinciding with zstar[j], where i = 1, ..., k,
         and j = 1, ..., L                                    */
-	int fij[k*L];
+	/* int fij[k*L]; replaced my next line as per Tomasz Melcer*/
+	int *fij = calloc(k*L, sizeof *fij);
 	/* lvec is an integer vector with length L, 
 		whose jth entry = \sum_{i=1}^{k} f_{ij}, i.e., 
            the multiplicity of zstar[j]                      */
-	int lvec[L];
+	/* int lvec[L]; replaced my next line as per Tomasz Melcer */
+	int *lvec = calloc(L, sizeof *lvec);
 	
 	/* for computation */
 	double mij;
@@ -279,7 +283,8 @@ void adkTestStat(double *adk, int k, double *x, int *ns){
 		free(samples[i]);
 	}
 	free(samples);
-	
+	free(lvec);
+	free(fij);
 }
 
  /* *****************************************
@@ -609,7 +614,6 @@ void adkPVal(double *pval, int Nsim, int k, double *x, int *ns,
 	
 	int nsum = getSum(ns, k); 
      	/* total sample size = n_1 + ... + n_k */
-	int index;
 	double adk[2];
 	/* initializes static variables */
 	initvals1(k, x, ns, zstar, L);
@@ -642,8 +646,6 @@ void adkPVal(double *pval, int Nsim, int k, double *x, int *ns,
 		
 	
 	} else { /* uses Nsim simulations to get p-value */
-		double randy;
-		double temp;
 		double adksim[2];
 		double xc[nsum]; /* copy of x */
 		
@@ -1081,10 +1083,10 @@ void contingency2xtSim0(int *Avec, int *Bvec, int *tnum,
  * modified 06/11/2015 Fritz Scholz
  ***************************/
 
-static int getQNdist; 
-            /* logical value to indicate whether generated QN
-               values are recorded in QNvec               */
-static double *QNvec; 
+/* static int getQNdist; 
+            logical value to indicate whether generated QN
+               values are recorded in QNvec               
+static double *QNvec; */
 
 
 /* initializes static variables */
@@ -1200,13 +1202,10 @@ void QNpvalue(double *pval, int Nsim, int k, double *rx,
               double ncomb, double *QNobs, double *QNvec) {
     
 	int i;
-	int j;
-	int Ri;
      int isim;
 
 	int nsum = getSum(ns, k); 
       	/* total sample size = n_1 + ... + n_k */
-	int index;
 	QNinitvals1(k,rx,ns);
 
 	/* get observed test statistic for the average rank score 
@@ -1234,8 +1233,6 @@ void QNpvalue(double *pval, int Nsim, int k, double *rx,
 		/* gets exact p-values */
 		pval[0] = pval[0] / ncomb;
 	} else { /* uses Nsim simulations to get p-value */
-		double randy;
-		double temp;
 		double QNsim[1];
 		double rc[nsum]; /* copy of rx */
 		
@@ -1315,7 +1312,7 @@ static double *mu; /* array of length k-1 for Wilcoxon means for
                       standardization */
 static double *tau; /* array of length k-1 for Wilcoxon std. 
                        devs. for standardization */
-static int getSteeldist; /* logical value to indicate whether 
+/* static int getSteeldist; logical value to indicate whether 
                             generated Steel values are recorded
                             in Steelvec*/
 static int count; /* keeps track of how many combinations have 
@@ -1409,7 +1406,6 @@ void SteelTestStat(double *Steel, int k, double *rx, int *ns){
 	int j;
         int m;
     	double Ri;
-    	double maxR;
     	int istart, iend;
 	istart = ns[0];
 	Ri = 0.0;
@@ -1503,13 +1499,10 @@ void Steelpvalue(double *pval, int Nsim, int k, double *rx,
                  double *Steelvec) {
     
 	int i;
-	int j;
-	int Ri;
     	int isim;
 
 	int nsum = getSum(ns, k); 
           /* total sample size = n_1 + ... + n_k */
-	int index;
 	Steelinitvals1(k, rx, ns, alt, mu, tau);
 	/* get observed test statistic for the average rank score
         vector rx in standardized form */
@@ -1538,8 +1531,6 @@ void Steelpvalue(double *pval, int Nsim, int k, double *rx,
 		/* gets exact p-values */
 		pval[0] = pval[0] / ncomb;
 	} else { /* uses Nsim simulations to get p-value */
-		double randy;
-		double temp;
 		double Steelsim[1];
 		double rc[nsum]; /* copy of rx */
 		
@@ -1949,14 +1940,11 @@ void SteelVec(int Nsim, int k, double *rx, int *ns,
 	int i;
 	int ix;
 	int ccount;
-	int j;
-	int Ri;
     	int isim;
 	int k1=k-1;
 
 	int nsum = getSum(ns, k); 
         /* total sample size = n_1 + ... + n_k */
-	int index;
 
 
 	/* uses R random number generator */
@@ -1976,8 +1964,6 @@ void SteelVec(int Nsim, int k, double *rx, int *ns,
                             MannWhitneyStats);
 		SteelexactVec(0, position, nsum);
 	} else { /* uses Nsim simulations to get p-value */
-		double randy;
-		double temp;
 		double Steelsim[k1];
 		double rc[nsum]; /* copy of rx */
 		
@@ -2149,8 +2135,8 @@ void conv(double *x1, double *p1, int *n1, double *x2,
 
 void convvec(double *x1, int *n1, double *x2, int *n2, 
              double *x, int *n) {
-    int i,j, M;
-    double xij, pij;
+    int i,j;
+    /* double xij, pij;  */
     n[0] = 0;
     for(i=0; i < n1[0]; i++){
 		for(j=0; j < n2[0]; j++){
@@ -2224,10 +2210,10 @@ void Harding0(int *k, int *L1, int *nn, int *nvec, double *freq){
  * modified 08/25/2015 Fritz Scholz
  ***************************/
 
-static int getJTdist; 
-            /* logical value to indicate whether generated JT
-               values are recorded in JTvec               */
-static double *JTvec; 
+/* static int getJTdist; 
+            logical value to indicate whether generated JT
+               values are recorded in JTvec               
+static double *JTvec; */
 
 
 /* initializes static variables */
@@ -2362,13 +2348,10 @@ void JTpvalue(double *pval, int Nsim, int k, double *rx,
               double ncomb, double *JTobs, double *JTvec) {
     
 	int i;
-	int j;
-	int Ri;
      	int isim;
 
 	int nsum = getSum(ns, k); 
       	/* total sample size = n_1 + ... + n_k */
-	int index;
 	JTinitvals1(k,rx,ns);
 
 	/* get observed test statistic for the score vector rx */
@@ -2395,8 +2378,6 @@ void JTpvalue(double *pval, int Nsim, int k, double *rx,
 		/* gets exact p-values */
 		pval[0] = pval[0] / ncomb;
 	} else { /* uses Nsim simulations to get p-value */
-		double randy;
-		double temp;
 		double JTsim[1];
 		double rc[nsum]; /* copy of rx */
 		
@@ -2483,3 +2464,31 @@ void randPerm(int nsum, double *rx, double *rc, int *ns){
 
 
 }
+
+static const
+R_CMethodDef cMethods[] = {
+	{"convvec", (DL_FUNC) &convvec, 6},
+	{"adkTestStat0", (DL_FUNC) &adkTestStat0, 6},
+	{"adkPVal0", (DL_FUNC) &adkPVal0, 11},
+	{"contingency2xtExact0", (DL_FUNC) &contingency2xtExact0, 6},
+	{"contingency2xtSim0", (DL_FUNC) &contingency2xtSim0, 6},
+	{"convC", (DL_FUNC) &conv, 9},
+	{"Harding0", (DL_FUNC) &Harding0, 5},
+	{"JTtest", (DL_FUNC) &JTtest, 10},
+	{"QNtest", (DL_FUNC) &QNtest, 10},
+	{"Steeltest", (DL_FUNC) &Steeltest, 13},
+	{"SteelConf", (DL_FUNC) &SteelConf, 6},
+	{NULL, NULL, 0}
+};
+
+void R_init_kSamples(DllInfo *info)
+{
+    	R_registerRoutines(info, 
+			cMethods, 
+			NULL, NULL, NULL);
+	R_useDynamicSymbols(info, TRUE);
+
+}
+
+
+
